@@ -30,6 +30,7 @@
 #include <near/types.h>
 
 struct near_adapter;
+struct near_device_driver;
 
 #include <near/log.h>
 
@@ -84,8 +85,10 @@ int __near_adapter_remove_target(uint32_t idx, uint32_t target_idx);
 int __near_adapter_add_device(uint32_t idx, uint8_t *nfcid, uint8_t nfcid_len);
 int __near_adapter_remove_device(uint32_t idx);
 int __near_adapter_set_dep_state(uint32_t idx, near_bool_t dep);
+near_bool_t __near_adapter_get_dep_state(uint32_t idx);
 void __near_adapter_tags_changed(uint32_t adapter_idx);
 void __near_adapter_devices_changed(uint32_t adapter_idx);
+void __near_adapter_listen(struct near_device_driver *driver);
 void __near_adapter_list(DBusMessageIter *iter, void *user_data);
 int __near_adapter_init(void);
 void __near_adapter_cleanup(void);
@@ -99,6 +102,7 @@ void __near_ndef_cleanup(void);
 int __near_ndef_record_register(struct near_ndef_record *record, char *path);
 void __near_ndef_record_free(struct near_ndef_record *record);
 char *__near_ndef_record_get_path(struct near_ndef_record *record);
+char *__near_ndef_record_get_type(struct near_ndef_record *record);
 const char *__near_ndef_get_uri_prefix(uint8_t id);
 struct near_ndef_message *__ndef_build_from_message(DBusMessage *msg);
 
@@ -131,7 +135,8 @@ struct near_device *__near_device_add(uint32_t idx, uint32_t target_idx,
 void __near_device_remove(struct near_device *device);
 int __near_device_listen(struct near_device *device, near_device_io_cb cb);
 int __near_device_push(struct near_device *device,
-			struct near_ndef_message *ndef, near_device_io_cb cb);
+			struct near_ndef_message *ndef, char *service_name,
+			near_device_io_cb cb);
 
 #include <near/tlv.h>
 
@@ -143,11 +148,6 @@ int __near_netlink_dep_link_up(uint32_t idx, uint32_t target_idx,
 				uint8_t comm_mode, uint8_t rf_mode);
 int __near_netlink_dep_link_down(uint32_t idx);
 int __near_netlink_adapter_enable(int idx, near_bool_t enable);
-int __near_netlink_activate_target(uint32_t adapter_idx,
-					uint32_t target_idx,
-					uint32_t protocol);
-int __near_netlink_deactivate_target(uint32_t adapter_idx,
-					uint32_t target_idx);
 int __near_netlink_init(void);
 void __near_netlink_cleanup(void);
 
@@ -161,6 +161,8 @@ void __near_plugin_cleanup(void);
 /* NFC Bluetooth Secure Simple Pairing */
 #define BT_MIME_V2_0		0
 #define BT_MIME_V2_1		1
+#define BT_MIME_STRING_2_0	"nokia.com:bt"
+#define BT_MIME_STRING_2_1	"application/vnd.bluetooth.ep.oob"
 
 int __near_bluetooth_init(void);
 void __near_bluetooth_cleanup(void);
@@ -169,7 +171,13 @@ int __near_bluetooth_parse_oob_record(uint8_t version, uint8_t *bt_data,
 int __near_bluetooth_pair(void *data);
 uint8_t *__near_bluetooth_local_get_properties(int *bt_data_len);
 
-int __near_handover_agent_register(const char *sender, const char *path);
-int __near_handover_agent_unregister(const char *sender, const char *path);
-int __near_handover_init(void);
-void __near_handover_cleanup(void);
+void __near_agent_ndef_parse_records(GList *records);
+int __near_agent_ndef_register(const char *sender, const char *path,
+						const char *record_type);
+int __near_agent_ndef_unregister(const char *sender, const char *path,
+						const char *record_type);
+int __near_agent_handover_register(const char *sender, const char *path);
+int __near_agent_handover_unregister(const char *sender, const char *path);
+
+int __near_agent_init(void);
+void __near_agent_cleanup(void);
